==> cucumber-groovy-1.2.3-sources.jar: cucumber/api/groovy/NL.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class NL {

    public static void Als(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Als(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dan(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dan(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void En(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void En(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Gegeven(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Gegeven(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Maar(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Maar(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Stel(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Stel(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

}

==> cucumber-groovy-2.0.1-sources.jar: cucumber/api/groovy/NL.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class NL {

    public static void Gegeven(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Gegeven(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Stel(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Stel(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Als(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Als(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Wanneer(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Wanneer(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dan(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Dan(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void En(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void En(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Maar(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Maar(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

}
